@@ -9,6 +9,7 @@ from libturpial.lib.services.media.preview.yfrog import YfrogMediaContent
 from libturpial.lib.services.media.preview.pictwitter import PicTwitterMediaContent
 from libturpial.lib.services.media.preview.viame import ViameMediaContent
 from libturpial.lib.services.media.preview.flickr import FlickrMediaContent
+from libturpial.lib.services.media.preview.instagram import InstagramMediaContent
 
 PREVIEW_MEDIA_SERVICES = {
     'imgur': ImgurMediaContent(),
@@ -18,4 +19,5 @@ PREVIEW_MEDIA_SERVICES = {
     'pic.twitter.com': PicTwitterMediaContent(),
     'via.me': ViameMediaContent(),
     'flic.kr': FlickrMediaContent(),
+    'instragram': InstagramMediaContent(),
 }
